SseClient class abstract

A Server-Sent Events (SSE) client.

Mixed-in types

Constructors

SseClient({required Uri serverUri, Client? httpClient, String? clientId})
Creates a new SseClient connected to the server at serverUri.
factory
SseClient.base()

Properties

clientId → String
The client ID used to identify this client to the server.
no setter
hashCode → int
The hash code for this object.
no setterinherited
onConnected → Future<void>
Completes when the server connection is established.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → StreamSink<Map<String, Object?>>
The sink for sending values to the other endpoint.
no setterinherited
stream → Stream<Map<String, Object?>>
The single-subscription stream that emits values from the other endpoint.
no setterinherited

Methods

cast<S>() → StreamChannel<S>
Returns a copy of this with the generic type coerced to S.
inherited
changeSink(StreamSink<Map<String, Object?>> change(StreamSink<Map<String, Object?>>)) → StreamChannel<Map<String, Object?>>
Returns a copy of this with sink replaced by change's return value.
inherited
changeStream(Stream<Map<String, Object?>> change(Stream<Map<String, Object?>>)) → StreamChannel<Map<String, Object?>>
Returns a copy of this with stream replaced by change's return value.
inherited
close() → void
Closes the connection to the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamChannel<Map<String, Object?>> other) → void
Connects this to other, so that any values emitted by either are sent directly to the other.
inherited
toString() → String
A string representation of this object.
inherited
transform<S>(StreamChannelTransformer<S, Map<String, Object?>> transformer) → StreamChannel<S>
Transforms this using transformer.
inherited
transformSink(StreamSinkTransformer<Map<String, Object?>, Map<String, Object?>> transformer) → StreamChannel<Map<String, Object?>>
Transforms only the sink component of this using transformer.
inherited
transformStream(StreamTransformer<Map<String, Object?>, Map<String, Object?>> transformer) → StreamChannel<Map<String, Object?>>
Transforms only the stream component of this using transformer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited